==> akonadi-search-22.03.80.tar.xz: akonadi-search-22.03.80/runner/plasma-krunner-pimcontacts.desktop.cmake <==
[Desktop Entry]
Name=PIM Contacts Search
Name[ar]=البحث في متراسلي PIM
Name[az]=PİM Kontaktları Axtarışı
Name[ca]=Cerca de contactes PIM
Name[ca@valencia]=Cerca de contactes PIM
Name[cs]=Vyhledávání kontaktů PIM
Name[da]=Søgning i PIM-kontakter
Name[de]=PIM-Kontaktsuche
Name[el]=Αναζήτηση επαφών PIM
Name[en_GB]=PIM Contacts Search
Name[es]=Búsqueda de contactos PIM
Name[et]=PIM-i kontaktide otsing
Name[eu]=PIM kontaktuen bilaketa
Name[fi]=PIM-yhteystietojen haku
Name[fr]=Recherche de contacts PIM
Name[gl]=Busca de contactos
Name[hi]=पीआईएम सम्पर्क खोज
Name[hsb]=Pytanje w PIM-kontaktach
Name[hu]=Névjegykereső
Name[ia]=Cerca de contactos de PIM
Name[it]=Ricerca contatti PIM
Name[ko]=PIM 연락처 검색
Name[nl]=PIM in contactpersonen zoeken
Name[nn]=Søk i e-postkontaktar
Name[pl]=Wyszukiwanie kontaktów ZIO
Name[pt]=Pesquisa de Contactos PIM
Name[pt_BR]=Pesquisa de Contatos PIM
Name[ru]=Поиск контактов в PIM
Name[sk]=Hľadanie kontaktov PIM
Name[sl]=Iskanjem PIM po stikih
Name[sr]=Претрага ПИМ контаката
Name[sr@ijekavian]=Претрага ПИМ контаката
Name[sr@ijekavianlatin]=Pretraga PIM kontakata
Name[sr@latin]=Pretraga PIM kontakata
Name[sv]=Kontaktsökning i personlig informationshantering
Name[tr]=PIM Bağlantılarını Ara
Name[uk]=Пошук у записах контактів PIM
Name[x-test]=xxPIM Contacts Searchxx
Name[zh_CN]=个人信息存储联系人搜索
Name[zh_TW]=PIM 聯絡人搜尋
Comment=Runner which searches through your contacts
Comment[ar]=مشغّل يبحث في متراسليك
Comment[az]=Kontaktları axtarmaq və açmaq üçün modul
Comment[ca]=Executor que cerca a través dels vostres contactes
Comment[ca@valencia]=Executor que cerca a través dels vostres contactes
Comment[da]=Runner som søger efter dine kontakter
Comment[de]=Runner, der Ihre Kontakte durchsucht
Comment[el]=Εκτελεστής αναζήτησης στις επαφές σας
Comment[en_GB]=Runner which searches through your contacts
Comment[es]=Lanzador que busca por sus contactos
Comment[et]=Käivitaja, mis otsib sinu kontaktides
Comment[eu]=Zure kontaktuetan barrena bilatzen duen exekutatzailea
Comment[fi]=Suoritusohjelma, joka etsii yhteystiedoista
Comment[fr]=Module Runner qui recherche dans vos contacts
Comment[gl]=Executor que busca contactos.
Comment[hi]=रनर जो आपके सम्पर्क खोजता है
Comment[hsb]=Program kotryž pyta we Wašich kontaktach
Comment[hu]=Keresés a névjegyek között
Comment[ia]=Cursor que cerca per tu contactos
Comment[it]=Esecutore che cerca tra i contatti
Comment[ko]=연락처를 검색하는 실행기
Comment[nl]=Programma dat uw contactpersonen doorzoekt
Comment[nn]=Køyrar som søkjer etter e-postkontaktar
Comment[pl]=Wyszukuje kontakty
Comment[pt]=Módulo de execução que pesquisa nos seus contactos
Comment[pt_BR]=Módulo de execução que pesquisa nos seus contatos
Comment[ru]=Модуль для поиска и открытия контактов
Comment[sk]=Program, ktorý prehľadáva vaše kontakty
Comment[sl]=Zaganjalnik, ki preišče vaše stike
Comment[sr]=Извођач који тражи кроз ваше контакте
Comment[sr@ijekavian]=Извођач који тражи кроз ваше контакте
Comment[sr@ijekavianlatin]=Izvođač koji traži kroz vaše kontakte
Comment[sr@latin]=Izvođač koji traži kroz vaše kontakte
Comment[sv]=Körprogram som söker igenom kontakter
Comment[tr]=Bağlantılarınızı arayacak olan araç
Comment[uk]=Засіб запуску для пошуку у записах ваших контактів
Comment[x-test]=xxRunner which searches through your contactsxx
Comment[zh_CN]=搜索您的联系人的运行器
Comment[zh_TW]=當搜尋你的聯絡人時執行
Type=Service
Icon=view-pim-contacts

X-KDE-ServiceTypes=Plasma/Runner
X-KDE-PluginInfo-Author=Daniel Vrátil
X-KDE-PluginInfo-Email=dvratil@kde.org
X-KDE-PluginInfo-Name=PIM Contacts Search Runner
X-KDE-PluginInfo-Version=1.0
X-KDE-PluginInfo-License=LGPL
X-KDE-PluginInfo-EnabledByDefault=true
X-KDE-ConfigModule=kf@QT_MAJOR_VERSION@/krunner/kcms/kcm_krunner_pimcontacts

==> akonadi-search-22.04.1.tar.xz: akonadi-search-22.04.1/runner/plasma-krunner-pimcontacts.desktop.cmake <==
[Desktop Entry]
Name=PIM Contacts Search
Name[ar]=البحث في متراسلي PIM
Name[az]=PİM Kontaktları Axtarışı
Name[ca]=Cerca de contactes PIM
Name[ca@valencia]=Busca de contactes PIM
Name[cs]=Vyhledávání kontaktů PIM
Name[da]=Søgning i PIM-kontakter
Name[de]=PIM-Kontaktsuche
Name[el]=Αναζήτηση επαφών PIM
Name[en_GB]=PIM Contacts Search
Name[es]=Búsqueda de contactos PIM
Name[et]=PIM-i kontaktide otsing
Name[eu]=PIM kontaktuen bilaketa
Name[fi]=PIM-yhteystietojen haku
Name[fr]=Recherche de contacts PIM
Name[gl]=Busca de contactos
Name[hi]=पीआईएम सम्पर्क खोज
Name[hsb]=Pytanje w PIM-kontaktach
Name[hu]=Névjegykereső
Name[ia]=Cerca de contactos de PIM
Name[it]=Ricerca contatti PIM
Name[ko]=PIM 연락처 검색
Name[nl]=PIM in contactpersonen zoeken
Name[nn]=Søk i e-postkontaktar
Name[pl]=Wyszukiwanie kontaktów ZIO
Name[pt]=Pesquisa de Contactos PIM
Name[pt_BR]=Pesquisa de Contatos PIM
Name[ru]=Поиск контактов в PIM
Name[sk]=Hľadanie kontaktov PIM
Name[sl]=Iskanjem PIM po stikih
Name[sr]=Претрага ПИМ контаката
Name[sr@ijekavian]=Претрага ПИМ контаката
Name[sr@ijekavianlatin]=Pretraga PIM kontakata
Name[sr@latin]=Pretraga PIM kontakata
Name[sv]=Kontaktsökning i personlig informationshantering
Name[tr]=PIM Bağlantılarını Ara
Name[uk]=Пошук у записах контактів PIM
Name[x-test]=xxPIM Contacts Searchxx
Name[zh_CN]=个人信息存储联系人搜索
Name[zh_TW]=PIM 聯絡人搜尋
Comment=Runner which searches through your contacts
Comment[ar]=مشغّل يبحث في متراسليك
Comment[az]=Kontaktları axtarmaq və açmaq üçün modul
Comment[ca]=Executor que cerca a través dels vostres contactes
Comment[ca@valencia]=Executor que busca a través dels vostres contactes
Comment[da]=Runner som søger efter dine kontakter
Comment[de]=Runner, der Ihre Kontakte durchsucht
Comment[el]=Εκτελεστής αναζήτησης στις επαφές σας
Comment[en_GB]=Runner which searches through your contacts
Comment[es]=Lanzador que busca por sus contactos
Comment[et]=Käivitaja, mis otsib sinu kontaktides
Comment[eu]=Zure kontaktuetan barrena bilatzen duen exekutatzailea
Comment[fi]=Suoritusohjelma, joka etsii yhteystiedoista
Comment[fr]=Module Runner qui recherche dans vos contacts
Comment[gl]=Executor que busca contactos.
Comment[hi]=रनर जो आपके सम्पर्क खोजता है
Comment[hsb]=Program kotryž pyta we Wašich kontaktach
Comment[hu]=Keresés a névjegyek között
Comment[ia]=Cursor que cerca per tu contactos
Comment[it]=Esecutore che cerca tra i contatti
Comment[ko]=연락처를 검색하는 실행기
Comment[nl]=Programma dat uw contactpersonen doorzoekt
Comment[nn]=Køyrar som søkjer etter e-postkontaktar
Comment[pl]=Wyszukuje kontakty
Comment[pt]=Módulo de execução que pesquisa nos seus contactos
Comment[pt_BR]=Módulo de execução que pesquisa nos seus contatos
Comment[ru]=Модуль для поиска и открытия контактов
Comment[sk]=Program, ktorý prehľadáva vaše kontakty
Comment[sl]=Zaganjalnik, ki preišče vaše stike
Comment[sr]=Извођач који тражи кроз ваше контакте
Comment[sr@ijekavian]=Извођач који тражи кроз ваше контакте
Comment[sr@ijekavianlatin]=Izvođač koji traži kroz vaše kontakte
Comment[sr@latin]=Izvođač koji traži kroz vaše kontakte
Comment[sv]=Körprogram som söker igenom kontakter
Comment[tr]=Bağlantılarınızı arayacak olan araç
Comment[uk]=Засіб запуску для пошуку у записах ваших контактів
Comment[x-test]=xxRunner which searches through your contactsxx
Comment[zh_CN]=搜索您的联系人的运行器
Comment[zh_TW]=當搜尋你的聯絡人時執行
Type=Service
Icon=view-pim-contacts

X-KDE-ServiceTypes=Plasma/Runner
X-KDE-PluginInfo-Author=Daniel Vrátil
X-KDE-PluginInfo-Email=dvratil@kde.org
X-KDE-PluginInfo-Name=PIM Contacts Search Runner
X-KDE-PluginInfo-Version=1.0
X-KDE-PluginInfo-License=LGPL
X-KDE-PluginInfo-EnabledByDefault=true
X-KDE-ConfigModule=kf@QT_MAJOR_VERSION@/krunner/kcms/kcm_krunner_pimcontacts
